---
title: <span class="badge object-type-scalar"></span> MilliAmpere
---
# <span class="badge object-type-scalar"></span> MilliAmpere

Energy: Milliampere (mA)

## Definition

```python
# Energy: Milliampere (mA)
MilliAmpere: typing.Literal["mamp"] = "mamp"
```
